==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/TaxDriver_EU.pm <==
package WebGUI::i18n::German::TaxDriver_EU;
use utf8;
our $I18N = {
  'accept when vies unavailable' => {
    'lastUpdated' => '1250973723',
    'message' => 'Falls VIES nicht verfügbar, nicht validierte MwSt-Nummern akzeptieren?'
  },
  'accept when vies unavailable help' => {
    'lastUpdated' => '1250974852',
    'message' => 'Wenn einer der Databases der VIES-Mitgliedsländer temporär ausfällt oder VIES-Überprüfung fehlerhaft war, können MwSt.-Nummern nicht geprüft werden. Wenn "ja" können MwST-Nummern dennoch verwendet werden. Das Format der MwSt.-Nummern wird übrigens immer und unabhängig vom VIES Service überprüft.'
  },
  'add' => {
    'lastUpdated' => '1243115405',
    'message' => 'Hinzufügen'
  },
  'add vat group' => {
    'lastUpdated' => '1243115433',
    'message' => 'MwSt-Satz hinzufügen'
  },
  'already has vat number' => {
    'lastUpdated' => '1243496090',
    'message' => 'Sie haben bereits eine MwSt-Nummer für dieses Land registriert.'
  },
  'approve' => {
    'lastUpdated' => '1243496141',
    'message' => 'Bestätigen'
  },
  'auto vies approval' => {
    'lastUpdated' => '1250973848',
    'message' => 'Automatische VIES Validierung?'
  },
  'auto vies approval help' => {
    'lastUpdated' => '1250973970',
    'message' => 'Wenn Sie hier "ja" einstellen, können durch VIES validierte MwSt.-Nummern direkt von Ihren Kunden verwendet werden. Wenn "nein", können nur von Ihnen freigegebene MwSt.-Nummern verwendet werden.'
  },
  'default group' => {
    'lastUpdated' => '1247509946',
    'message' => 'Standardgruppe'
  },
  'delete group' => {
    'lastUpdated' => '1247509956',
    'message' => 'Löschen'
  },
  'deny' => {
    'lastUpdated' => '1243115512',
    'message' => 'Ablehnen'
  },
  'general configuration' => {
    'lastUpdated' => '1247509931',
    'message' => 'Allgemeine Konfiguration'
  },
  'group name' => {
    'lastUpdated' => '1247509776',
    'message' => 'MwSt.-Gruppe'
  },
  'illegal country code' => {
    'lastUpdated' => '1247509799',
    'message' => 'Falscher Ländercode'
  },
  'make default' => {
    'lastUpdated' => '1243494923',
    'message' => 'Als Standardeinstellung verwenden'
  },
  'rate' => {
    'lastUpdated' => '1243115697',
    'message' => '%-Satz'
  },
  'select country' => {
    'lastUpdated' => '1243495997',
    'message' => 'Land auswählen'
  },
  'shop country' => {
    'lastUpdated' => '1243115574',
    'message' => 'Land zum Shop'
  },
  'shop country help' => {
    'lastUpdated' => '1252473216',
    'message' => 'Wählen Sie das Land, in dem Ihr Shop angesiedelt ist. Wenn Ihr Land nicht Teil der EU ist, können Sie dieses Steuer-Plugin nicht verwenden.'
  },
  'user' => {
    'lastUpdated' => '1243115588',
    'message' => 'Benutzer'
  },
  'user template' => {
    'lastUpdated' => '1247509835',
    'message' => 'Vorlage Benutzerschirm'
  },
  'user template help' => {
    'lastUpdated' => '1247509914',
    'message' => 'Vorlage für den Benutzerbildschirm, wo ein Benutzer seine MwSt.-Nummern eingeben kann.'
  },
  'vat group' => {
    'lastUpdated' => '1243115602',
    'message' => 'MwSt-Satz'
  },
  'vat groups' => {
    'lastUpdated' => '1243496056',
    'message' => 'MwSt-Sätze'
  },
  'vat number' => {
    'lastUpdated' => '1243496063',
    'message' => 'MwSt-Nummer'
  },
  'vat number invalid' => {
    'lastUpdated' => '1243496077',
    'message' => 'Die MwSt-Nummer ist ungültig'
  },
  'vat numbers' => {
    'lastUpdated' => '1243496069',
    'message' => 'MwSt-Nummern'
  },
  'vies error code' => {
    'lastUpdated' => '1250973806',
    'message' => 'VIES Fehlercode'
  },
  'vies unavailable' => {
    'lastUpdated' => '1250973778',
    'message' => 'Nummernvalidierung derzeit nicht verfügbar. Bitte kontrolieren Sie das später. '
  },
  'vies validated' => {
    'lastUpdated' => '1250973795',
    'message' => 'VIES validiert.'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/TaxDriver_EU.pm <==
package WebGUI::i18n::German::TaxDriver_EU;
use utf8;
our $I18N = {
  'Add another VAT number' => {
    'lastUpdated' => '1296988429',
    'message' => 'Eine weitere Umsatzsteuernummer hinzufügen'
  },
  'Approved for use' => {
    'lastUpdated' => '1296988453',
    'message' => 'Zur Nutzung freigegeben'
  },
  'Enter VAT numbers' => {
    'lastUpdated' => '1296988467',
    'message' => 'Umsatzsteuernummern eingeben'
  },
  'accept when vies unavailable' => {
    'lastUpdated' => '1250973723',
    'message' => 'Falls VIES nicht verfügbar, nicht validierte MwSt-Nummern akzeptieren?'
  },
  'accept when vies unavailable help' => {
    'lastUpdated' => '1250974852',
    'message' => 'Wenn einer der Databases der VIES-Mitgliedsländer temporär ausfällt oder VIES-Überprüfung fehlerhaft war, können MwSt.-Nummern nicht geprüft werden. Wenn "ja" können MwST-Nummern dennoch verwendet werden. Das Format der MwSt.-Nummern wird übrigens immer und unabhängig vom VIES Service überprüft.'
  },
  'add' => {
    'lastUpdated' => '1243115405',
    'message' => 'Hinzufügen'
  },
  'add vat group' => {
    'lastUpdated' => '1243115433',
    'message' => 'MwSt-Satz hinzufügen'
  },
  'already has vat number' => {
    'lastUpdated' => '1243496090',
    'message' => 'Sie haben bereits eine MwSt-Nummer für dieses Land registriert.'
  },
  'approve' => {
    'lastUpdated' => '1243496141',
    'message' => 'Bestätigen'
  },
  'auto vies approval' => {
    'lastUpdated' => '1250973848',
    'message' => 'Automatische VIES Validierung?'
  },
  'auto vies approval help' => {
    'lastUpdated' => '1250973970',
    'message' => 'Wenn Sie hier "ja" einstellen, können durch VIES validierte MwSt.-Nummern direkt von Ihren Kunden verwendet werden. Wenn "nein", können nur von Ihnen freigegebene MwSt.-Nummern verwendet werden.'
  },
  'default group' => {
    'lastUpdated' => '1247509946',
    'message' => 'Standardgruppe'
  },
  'delete group' => {
    'lastUpdated' => '1247509956',
    'message' => 'Löschen'
  },
  'deny' => {
    'lastUpdated' => '1243115512',
    'message' => 'Ablehnen'
  },
  'general configuration' => {
    'lastUpdated' => '1247509931',
    'message' => 'Allgemeine Konfiguration'
  },
  'group name' => {
    'lastUpdated' => '1247509776',
    'message' => 'MwSt.-Gruppe'
  },
  'illegal country code' => {
    'lastUpdated' => '1247509799',
    'message' => 'Falscher Ländercode'
  },
  'make default' => {
    'lastUpdated' => '1243494923',
    'message' => 'Als Standardeinstellung verwenden'
  },
  'rate' => {
    'lastUpdated' => '1243115697',
    'message' => '%-Satz'
  },
  'select country' => {
    'lastUpdated' => '1243495997',
    'message' => 'Land auswählen'
  },
  'shop country' => {
    'lastUpdated' => '1243115574',
    'message' => 'Land zum Shop'
  },
  'shop country help' => {
    'lastUpdated' => '1252473216',
    'message' => 'Wählen Sie das Land, in dem Ihr Shop angesiedelt ist. Wenn Ihr Land nicht Teil der EU ist, können Sie dieses Steuer-Plugin nicht verwenden.'
  },
  'user' => {
    'lastUpdated' => '1243115588',
    'message' => 'Benutzer'
  },
  'user template' => {
    'lastUpdated' => '1247509835',
    'message' => 'Vorlage Benutzerschirm'
  },
  'user template help' => {
    'lastUpdated' => '1247509914',
    'message' => 'Vorlage für den Benutzerbildschirm, wo ein Benutzer seine MwSt.-Nummern eingeben kann.'
  },
  'vat group' => {
    'lastUpdated' => '1243115602',
    'message' => 'MwSt-Satz'
  },
  'vat groups' => {
    'lastUpdated' => '1243496056',
    'message' => 'MwSt-Sätze'
  },
  'vat number' => {
    'lastUpdated' => '1243496063',
    'message' => 'MwSt-Nummer'
  },
  'vat number invalid' => {
    'lastUpdated' => '1243496077',
    'message' => 'Die MwSt-Nummer ist ungültig'
  },
  'vat numbers' => {
    'lastUpdated' => '1243496069',
    'message' => 'MwSt-Nummern'
  },
  'vies error code' => {
    'lastUpdated' => '1250973806',
    'message' => 'VIES Fehlercode'
  },
  'vies unavailable' => {
    'lastUpdated' => '1250973778',
    'message' => 'Nummernvalidierung derzeit nicht verfügbar. Bitte kontrolieren Sie das später. '
  },
  'vies validated' => {
    'lastUpdated' => '1250973795',
    'message' => 'VIES validiert.'
  }
}
;

1;
